==> libreoffice_6.0.7.orig.tar.xz: libreoffice-6.0.7/ucb/source/ucp/ftp/ftpdynresultset.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

#include <com/sun/star/sdbc/XResultSet.hpp>
#include "ftpdynresultset.hxx"
#include "ftpresultsetfactory.hxx"

using namespace com::sun::star::lang;
using namespace com::sun::star::sdbc;
using namespace com::sun::star::ucb;
using namespace com::sun::star::uno;


using namespace ftp;


// DynamicResultSet Implementation.


DynamicResultSet::DynamicResultSet(
    const Reference< XComponentContext >& rxContext,
    const OpenCommandArgument2& rCommand,
    ResultSetFactory* pFactory )
    : ResultSetImplHelper( rxContext, rCommand ),
      m_pFactory( pFactory )
{
}

DynamicResultSet::~DynamicResultSet()
{
}


// Non-interface methods.


void DynamicResultSet::initStatic()
{
    m_xResultSet1.set( m_pFactory->createResultSet() );
}


void DynamicResultSet::initDynamic()
{
    m_xResultSet1.set( m_pFactory->createResultSet() );

    m_xResultSet2 = m_xResultSet1;
}


/* vim:set shiftwidth=4 softtabstop=4 expandtab: */

==> libreoffice-6.2.2.2.tar.xz: libreoffice-6.2.2.2/ucb/source/ucp/ftp/ftpdynresultset.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

#include <com/sun/star/sdbc/XResultSet.hpp>
#include "ftpdynresultset.hxx"
#include "ftpresultsetfactory.hxx"

using namespace com::sun::star::lang;
using namespace com::sun::star::sdbc;
using namespace com::sun::star::ucb;
using namespace com::sun::star::uno;


using namespace ftp;


// DynamicResultSet Implementation.


DynamicResultSet::DynamicResultSet(
    const Reference< XComponentContext >& rxContext,
    const OpenCommandArgument2& rCommand,
    std::unique_ptr<ResultSetFactory> pFactory )
    : ResultSetImplHelper( rxContext, rCommand ),
      m_pFactory( std::move(pFactory) )
{
}

DynamicResultSet::~DynamicResultSet()
{
}


// Non-interface methods.


void DynamicResultSet::initStatic()
{
    m_xResultSet1.set( m_pFactory->createResultSet() );
}


void DynamicResultSet::initDynamic()
{
    m_xResultSet1.set( m_pFactory->createResultSet() );

    m_xResultSet2 = m_xResultSet1;
}


/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
